# Table of Contents

- [workspace-administration](<./workspace-administration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Workspace Administration](<./Workspace-Administration.md>)
  - [Navigating to the Administration Area](<./Workspace-Administration/Navigating-to-the-Administration-Area.md>)
  - [Configuring Workspace Settings](<./Workspace-Administration/Configuring-Workspace-Settings.md>)
  - [Managing User Access and Permissions](<./Workspace-Administration/Managing-User-Access-and-Permissions.md>)
  - [Switching Your User Role](<./Workspace-Administration/Switching-Your-User-Role.md>)
  - [Enabling Maintenance Mode for a Workspace](<./Workspace-Administration/Enabling-Maintenance-Mode-for-a-Workspace.md>)
  - [Finding the Workspace ID](<./Workspace-Administration/Finding-the-Workspace-ID.md>)
  - [Monitoring the Usage and Adoption of SAP LeanIX](<./Workspace-Administration/Monitoring-the-Usage-and-Adoption-of-SAP-LeanIX.md>)
